=============
UNFCCC DI API
=============


.. image:: https://img.shields.io/pypi/v/unfccc_di_api.svg
        :target: https://pypi.python.org/pypi/unfccc_di_api
        :alt: PyPI release

.. image:: https://readthedocs.org/projects/unfccc-di-api/badge/?version=latest
        :target: https://unfccc-di-api.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.4457484.svg
   :target: https://doi.org/10.5281/zenodo.4457484


Python wrapper around the `Flexible Query API <https://di.unfccc.int/flex_annex1>`_ of
the UNFCCC.


* Free software: Apache Software License 2.0
* Documentation: https://unfccc-di-api.readthedocs.io.


Features
--------

* High-level API to query all information for a given party.
* Low-level API to selectively query information with the same resolution as in the
  UNFCCC web query tool.

Citation
--------
If you use this library and want to cite it, please cite it as:

Mika Pflüger. (2021, January 22). pik-primap/unfccc_di_api: Initial stable release
(Version v1.0.0). Zenodo. http://doi.org/10.5281/zenodo.4457484
